.\".VA
.TH PFORT 1L "10 August 1986"
.SH NAME
pfort \- a FORTRAN code portability verifier.
.SH SYNOPSIS
.B pfort
\fB[-D] [-R] [-S]\fP \fIfile\fP
.SH DESCRIPTION
.I Pfort
checks FORTRAN code for portability.  Also referred to as the Extended
PFORT Verifier,
this program takes FORTRAN code appearing in \fIfile\fP (one file only,
no wildcards permitted) and checks it
for the presence of non-standard (and hence probably non-portable) code.
The FORTRAN file should use the standard extension \fI.f\fP.
The source file must not contain tab characters or
lower-case letters in  FORTRAN keywords.
.PP
Options can appear in a options file \fI*.opt\fP, using the same basename
as for the source file.  If such a file does not exist, \fBpfort\fP
looks for a file called \fIpfort.opt\fP in the current directory, and then
for a file of that name in the user's home directory.
Output appears in a listing file (with extension \fI.pfl\fP) and
a declaration file (which uses extension \fI.dcl\fP).
.PP
This extended Verifier should not be confused with its parent program
of the same name.
.SH OPTIONS (COMMAND LINE)
There are two sets of options; one set is specified on the command line,
and the other must appear in an options file or the source code.
Three option switches are recognized on the command line:
.TP
.B \-D
(Declare Statements)
Write declarations for all undeclared FORTRAN variables
to a declaration (\fI*.dcl\fP) file.
If this option is omitted or all variables are explicitly declared, the
file is not produced.
.TP
.B \-R
(Reprocess) Execute even if the listing (\fI*.pfl\fP) file is newer than the
FORTRAN (\fI*.for\fP) file.  Normally, processing is terminated in such a case,
just as the COMPILE/LOAD/EXECUTE commands normally do not recompile
unnecessarily.
.TP
.B \-S
(SFTRAN3)
If the declare file is produced, SFTRAN3 preprocessor variables
of the form \fINPRnnn\fP, \fINXnnnn\fP, \fIN2nnnn\fP,
and \fIN3nnnn\fP (\fIn\fP = digit) will be omitted
from the declarations.  This makes the declaration file suitable for
inclusion in the SFTRAN3 source code.
.SH OPTIONS (OPTIONS FILE)
If an options (\fI*.opt\fP) file exists, it should contain only one line,
of the form:
.br
\fIC* op1,op2,...,opn\fP
.br
where the options are one- or two-letter codes separated by
commas and any number of spaces.
Such an options line may also be placed directly into the FORTRAN source
file.
.TP
.B C
Compile program after successful execution.
.TP
.B NC
Do not compile program (default).
.TP
.B F
Force continued execution after finding illegal statements (default).
.TP
.B NF
Flush to end of program unit after an illegal statement.
.TP
.B L
Print a listing of each program unit (default).
.TP
.B NL
Do not print a listing.
.TP
.B P
Perform inter-program-unit checks on this input (default).
To get the maximum benefit from this option, it is advisable
to concatenate all routines for a complete program into a
single file which is then input to PFORT.
.TP
.B NP
Do not perform inter-program-unit checks.
.TP
.B R
Gather and print cross references for all symbols for each program unit (default).
.TP
.B NR
Do not gather and print cross references.
.TP
.B S
Print a symbol table for each program unit (default).
.TP
.B NS
Do not print a symbol table.
.SH FILES
.TP 2.2i
/usr/local/plot79/pfortdir/*
files required to make \fIpfort\fP
.TP
/usr/local/plot79/pfort
executable file
.TP
/usr/local/plot79/define
various environment definitions, an appropriate subset of which should be
placed in the user's \fI.cshrc\fP or \fI.profile\fP file
.SH "SEE ALSO"
document (1L), drawit(1L), grapht(1L), graph3t(1L), lptops(1L),
piechtt(1L), plot79-intro(1L), plot79(1L), pluto(1L), pretty(1L), rdinfo(1L),
sf3(1L), slides(1L), tekalw(1L), tkvecs(1L), tmacro(1L), world(1L)
.SH AUTHOR
The original PFORT Verifier was written by AT&T Bell Laboratories.
By agreement with them, this improved version is known as the
Extended PFORT Verifier.
.br
Nelson H. F. Beebe, Ph.D.
.br
Center for Scientific Computing
.br
South Physics Building
.br
University of Utah
.br
Salt Lake City, UT 84112
.br
Tel: (801) 581-5254
.br
(Manual page by R. P. C. Rodgers, Computer Applications in Laboratory
Medicine Project, UCSF, San Francisco, CA 94143).
